cgexplore.optimisation.CGOMMSinglePoint
=======================================

.. currentmodule:: cgexplore.optimisation

.. autoclass:: CGOMMSinglePoint
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CGOMMSinglePoint.calculate_molecule_energy_decomposition
   
   

   
   
   